Package: PSCBS
Version: 0.68.0
Depends: R (>= 3.2.0)
Imports: R.methodsS3 (>= 1.8.2), R.oo (>= 1.25.0), R.utils (>= 2.12.0),
        R.cache (>= 0.16.0), matrixStats (>= 0.62.0), aroma.light (>=
        2.4.0), DNAcopy (>= 1.42.0), future (>= 1.28.0), parallel,
        graphics, grDevices, stats, utils
Suggests: R.rsp (>= 0.45.0), R.devices (>= 2.17.1), ggplot2 (>= 3.2.1)
SuggestsNote: BioC (>= 3.1)
VignetteBuilder: R.rsp
Title: Analysis of Parent-Specific DNA Copy Numbers
Authors@R: c(
  person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                 email="henrikb@braju.com"),
  person("Pierre", "Neuvial", role="aut"),
  person("Venkatraman E.", "Seshan", role="aut"),
  person("Adam B.", "Olshen", role="aut"),
  person("Paul T.", "Spellman", role="aut"),
  person("Richard A.", "Olshen", role="aut"),
  person("Frank E", "Harrell Jr", role="ctb",
         comment = "Weighted quantile estimator adopted from Hmisc::wtd.quantile()"))
Description: Segmentation of allele-specific DNA copy number data and detection of regions with abnormal copy number within each parental chromosome.  Both tumor-normal paired and tumor-only analyses are supported.
License: GPL (>= 2)
LazyLoad: TRUE
ByteCompile: TRUE
biocViews: aCGH, CopyNumberVariants, SNP, Microarray, OneChannel,
        TwoChannel, Genetics
URL: https://github.com/HenrikBengtsson/PSCBS
BugReports: https://github.com/HenrikBengtsson/PSCBS/issues
NeedsCompilation: no
Packaged: 2025-04-18 18:47:19 UTC; henrik
Author: Henrik Bengtsson [aut, cre, cph],
  Pierre Neuvial [aut],
  Venkatraman E. Seshan [aut],
  Adam B. Olshen [aut],
  Paul T. Spellman [aut],
  Richard A. Olshen [aut],
  Frank E Harrell Jr [ctb] (Weighted quantile estimator adopted from
    Hmisc::wtd.quantile())
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2025-04-18 19:40:02 UTC
Built: R 4.6.0; ; 2026-04-27 05:35:11 UTC; unix
